﻿using Infragistics.Windows.DataPresenter;
using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Collections.Specialized;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace CardViewAndGridViewStyle
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        MainVM vm;
        public MainWindow()
        {
            InitializeComponent();
            vm = new MainVM();
            DataContext = vm;
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            vm.GridData.Add(new Data { Label = "Test" });
        }

        private void Button_Click_1(object sender, RoutedEventArgs e)
        {
            vm.GridData.RemoveAt(0);
        }

        private void Button_Click_2(object sender, RoutedEventArgs e)
        {
            vm.GridData = Data.GetData(3, 10, 20);
        }
    }

    public class XamDataPresenterEx : XamDataPresenter
    {
        protected override void OnPropertyChanged(DependencyPropertyChangedEventArgs e)
        {
            base.OnPropertyChanged(e);

            if (e.Property.Name.Equals("DataSource"))
            {
                UpdateView();

                if (e.OldValue is INotifyCollectionChanged)
                {
                    (e.OldValue as INotifyCollectionChanged).CollectionChanged -= XamDataPresenterEx_CollectionChanged;
                }

                if (e.NewValue is INotifyCollectionChanged)
                {
                    (e.NewValue as INotifyCollectionChanged).CollectionChanged += XamDataPresenterEx_CollectionChanged;
                }
            }
        }

        void XamDataPresenterEx_CollectionChanged(object sender, NotifyCollectionChangedEventArgs e)
        {
            UpdateView();
        }

        private void UpdateView()
        {
            IList source = DataSource as IList;
            if (source != null)
            {
                int count = source.Count;

                if (count == 1)
                {
                    View = new CardView();
                }
                else
                {
                    View = new Infragistics.Windows.DataPresenter.GridView();
                }
            }
        }
    }
    

    public class MainVM : INotifyPropertyChanged
    {

        public MainVM()
        {
            GridData = Data.GetData(1, 10, 12); 
        }


        private ObservableCollection<Data> data;
        public ObservableCollection<Data> GridData
        {
            get { return data; }
            set { data = value; PropChanged("GridData"); }
        }

 
        public event PropertyChangedEventHandler PropertyChanged;
        public void PropChanged(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }
    }


    public class Data : INotifyPropertyChanged
        {
            private int open;
            private int close;
            private int high;
            private int low;
            private int value;
            private string label;
            private DateTime date;


            public DateTime Date
            {
                get { return date; }
                set
                {
                    date = value;
                    PropChanged("Date");
                }
            }


            public string Label
            {
                get { return label; }
                set
                {
                    label = value;
                    PropChanged("Label");
                }
            }

            public int Open
            {
                get { return open; }
                set
                {
                    open = value;
                    PropChanged("Open");
                }
            }

            public int Close
            {
                get { return close; }
                set
                {
                    close = value;
                    PropChanged("Close");
                }
            }

            public int High
            {
                get { return high; }
                set
                {
                    high = value;
                    PropChanged("High");
                }
            }

            public int Low
            {
                get { return low; }
                set
                {
                    low = value;
                    PropChanged("Low");
                }
            }

            public int Value
            {
                get { return value; }
                set
                {
                    this.value = value;
                    PropChanged("Value");
                }
            }

            public double Avarage
            {
                get
                {
                    return (Open + Close + High + Low) / 4;
                }
            }

            public static ObservableCollection<Data> GetData(int points, int rangeStart, int rangeEnd)
            {
                ObservableCollection<Data> data = new ObservableCollection<Data>();
                Random r = new Random();
                for (int i = 0; i < points; i++)
                {
                    data.Add(new Data
                    {
                        Date = DateTime.Now.AddDays(i),
                        Label = "Item " + i,
                        Open = r.Next(rangeStart, rangeEnd),
                        Close = r.Next(rangeStart, rangeEnd),
                        High = r.Next(rangeStart, rangeEnd),
                        Low = r.Next(rangeStart, rangeEnd),
                        Value = r.Next(rangeStart, rangeEnd),
                    });
                }

                return data;
            }

            public event PropertyChangedEventHandler PropertyChanged;

            public void PropChanged(string name)
            {
                if (PropertyChanged != null)
                    PropertyChanged(this, new PropertyChangedEventArgs(name));
            }
        }

    }

